This is the mail archive of the gdb-patches@sources.redhat.com mailing list for the GDB project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[PATCH RFA] fix some sim spelling errors.


So, I've started looking at 'sim' again...  Anyway, while doing so, I
noticed a bunch of spelling errors that were just too obvious to
ignore...  8-)


Any objections to the following?

I didn't fix things which i thought might have been valid spellings
in, uh, a different part of the world or which the dictionary i
consulted considered acceptable (but less-used or less-desirable),
even if ispell or spell whined about them.  8-)

I'd normally call this an obvious patch, but, well, some might see
this as undesirable because it changes the files.  So, i figured I'd
ask first.  If this is OK, i'll call future similar changes obvious.


chris
===================================================================
[sim/common/ChangeLog]
2002-02-09  Chris Demetriou  <cgd@broadcom.com>

	* callback.c: Fix some spelling errors.
	* hw-device.h: Likewise.
	* hw-tree.c: Likewise.
	* sim-abort.c: Likewise.
	* sim-alu.h: Likewise.
	* sim-core.h: Likewise.
	* sim-events.c: Likewise.
	* sim-events.h: Likewise.
	* sim-fpu.h: Likewise.
	* sim-profile.h: Likewise.
	* sim-utils.c: Likewise.

Index: callback.c
===================================================================
RCS file: /cvs/src/src/sim/common/callback.c,v
retrieving revision 1.2
diff -u -r1.2 callback.c
--- callback.c	2000/02/08 20:54:27	1.2
+++ callback.c	2002/02/10 07:19:48
@@ -726,7 +726,7 @@
    TS is ignored.
 
    The result is the size of the target's stat struct,
-   or zero if an error occured during the translation.  */
+   or zero if an error occurred during the translation.  */
 
 int
 cb_host_to_target_stat (cb, hs, ts)
Index: hw-device.h
===================================================================
RCS file: /cvs/src/src/sim/common/hw-device.h,v
retrieving revision 1.1.1.1
diff -u -r1.1.1.1 hw-device.h
--- hw-device.h	1999/04/16 01:34:57	1.1.1.1
+++ hw-device.h	2002/02/10 07:19:48
@@ -172,7 +172,7 @@
    node is described as the bus owner and is responisble for
    co-ordinating bus operations. On the bus, a SPACE:ADDR pair is used
    to specify an address.  A device that is both a bus owner (parent)
-   and bus client (child) are refered to as a bridging device.
+   and bus client (child) are referred to as a bridging device.
 
    A child performing a data (DMA) transfer will pass its request to
    the bus owner (the devices parent).  The bus owner will then either
Index: hw-tree.c
===================================================================
RCS file: /cvs/src/src/sim/common/hw-tree.c,v
retrieving revision 1.1.1.2
diff -u -r1.1.1.2 hw-tree.c
--- hw-tree.c	1999/09/22 03:28:06	1.1.1.2
+++ hw-tree.c	2002/02/10 07:19:48
@@ -681,7 +681,7 @@
       /* copy it in */
       if (*chp == '"')
 	{
-	  /* a quoted string - watch for '\' et.al. */
+	  /* a quoted string - watch for '\' et al. */
 	  /* estimate the size and allocate space for it */
 	  int pos;
 	  chp++;
Index: sim-abort.c
===================================================================
RCS file: /cvs/src/src/sim/common/sim-abort.c,v
retrieving revision 1.1.1.1
diff -u -r1.1.1.1 sim-abort.c
--- sim-abort.c	1999/04/16 01:34:57	1.1.1.1
+++ sim-abort.c	2002/02/10 07:19:48
@@ -28,7 +28,7 @@
    jump right out of the simulator.
 
    It is intended as a holder for simulators that have started to use
-   sim-core et.al. but are not yet in a position to use sim-engine
+   sim-core et al. but are not yet in a position to use sim-engine
    (the setjmp/longjmp code). */
 
 
Index: sim-core.h
===================================================================
RCS file: /cvs/src/src/sim/common/sim-core.h,v
retrieving revision 1.1.1.2
diff -u -r1.1.1.2 sim-core.h
--- sim-core.h	1999/04/26 18:31:38	1.1.1.2
+++ sim-core.h	2002/02/10 07:19:48
@@ -167,7 +167,7 @@
 /* Variable sized read/write
 
    Transfer a variable sized block of raw data between the host and
-   target.  Should any problems occure, the number of bytes
+   target.  Should any problems occur, the number of bytes
    successfully transfered is returned.
 
    No host/target byte endian conversion is performed.  No xor-endian
@@ -213,7 +213,7 @@
 /* XOR version of variable sized read/write.
 
    Transfer a variable sized block of raw data between the host and
-   target.  Should any problems occure, the number of bytes
+   target.  Should any problems occur, the number of bytes
    successfully transfered is returned.
 
    No host/target byte endian conversion is performed.  If applicable
Index: sim-events.h
===================================================================
RCS file: /cvs/src/src/sim/common/sim-events.h,v
retrieving revision 1.2
diff -u -r1.2 sim-events.h
--- sim-events.h	2000/07/27 11:37:34	1.2
+++ sim-events.h	2002/02/10 07:19:48
@@ -245,7 +245,7 @@
  int slip);
 
 
-/* Progress time such that an event shall occure upon the next call to
+/* Progress time such that an event shall occur upon the next call to
    sim_events tick */
 
 #if 0
Index: sim-fpu.h
===================================================================
RCS file: /cvs/src/src/sim/common/sim-fpu.h,v
retrieving revision 1.5
diff -u -r1.5 sim-fpu.h
--- sim-fpu.h	2002/01/20 04:09:23	1.5
+++ sim-fpu.h	2002/02/10 07:19:48
@@ -321,7 +321,7 @@
 
 /* Specific comparison operators
 
-   For NaNs et.al., the comparison operators will set IS to zero and
+   For NaNs et al., the comparison operators will set IS to zero and
    return a nonzero result. */
 
 INLINE_SIM_FPU (int) sim_fpu_lt (int *is, const sim_fpu *l, const sim_fpu *r);
Index: sim-profile.h
===================================================================
RCS file: /cvs/src/src/sim/common/sim-profile.h,v
retrieving revision 1.2
diff -u -r1.2 sim-profile.h
--- sim-profile.h	2000/08/15 18:39:02	1.2
+++ sim-profile.h	2002/02/10 07:19:48
@@ -96,7 +96,7 @@
 #define WITH_PROFILE_CORE_P (WITH_PROFILE & PROFILE_core)
 
 /* If MAX_TARGET_MODES isn't defined, we can't do memory profiling.
-   ??? It is intended that this is a temporary occurence.  Normally
+   ??? It is intended that this is a temporary occurrence.  Normally
    MAX_TARGET_MODES is defined.  */
 #ifndef MAX_TARGET_MODES
 #undef WITH_PROFILE_MEMORY_P
Index: sim-utils.c
===================================================================
RCS file: /cvs/src/src/sim/common/sim-utils.c,v
retrieving revision 1.4
diff -u -r1.4 sim-utils.c
--- sim-utils.c	2001/04/25 21:14:28	1.4
+++ sim-utils.c	2002/02/10 07:19:48
@@ -314,7 +314,7 @@
 }
 
 /* Return the elapsed time in milliseconds since START.
-   The actual time may be cpu usage (prefered) or wall clock.  */
+   The actual time may be cpu usage (preferred) or wall clock.  */
 
 unsigned long
 sim_elapsed_time_since (start)


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: sim-alu.h
===================================================================
RCS file: /cvs/src/src/sim/common/sim-alu.h,v
retrieving revision 1.1.1.1
diff -u -r1.1.1.1 sim-alu.h
--- sim-alu.h	1999/04/16 01:34:57	1.1.1.1
+++ sim-alu.h	2002/02/10 07:19:48
@@ -36,7 +36,7 @@
 
    Code using this module includes it into sim-main.h and then, as a
    convention, defines macro's ALU*_END that records the result of any
-   aritmetic performed.  Ex:
+   arithmetic performed.  Ex:
 
    	#include "sim-alu.h"
 	#define ALU32_END(RES) \
@@ -73,7 +73,7 @@
 	ALU*_RESULT: Generic ALU result output.
 
    	ALU*_HAD_OVERFLOW: Returns a nonzero value if signed overflow
-   	occured.
+   	occurred.
 
 	ALU*_OVERFLOW_RESULT: If the macro ALU*_HAD_OVERFLOW is being
 	used this is the most efficient result available.  Ex:
@@ -84,8 +84,8 @@
 		(RES) = ALU16_OVERFLOW_RESULT
    
    	ALU*_HAD_CARRY_BORROW: Returns a nonzero value if unsigned
-   	overflow or underflow (also refered to as carry and borrow)
-   	occured.
+   	overflow or underflow (also referred to as carry and borrow)
+   	occurred.
 
 	ALU*_CARRY_BORROW_RESULT: If the macro ALU*_HAD_CARRY_BORROW is being
 	used this is the most efficient result available.  Ex:
@@ -132,7 +132,7 @@
 
 
 
 /* Twos complement aritmetic - addition/subtraction - carry/borrow
    (or you thought you knew the answer to 0-0)
 
    
@@ -154,9 +154,9 @@
    UMAXn: The upper bound of an unsigned N bit value (the lower
    bound is always zero).
 
-   Un: UMAXn + 1.  Unsigned arrithmetic is computed `modulo (Un)'.  
+   Un: UMAXn + 1.  Unsigned arithmetic is computed `modulo (Un)'.  
 
-   X[p]: Is bit P of X.  X[0] denotes the least signifant bit.
+   X[p]: Is bit P of X.  X[0] denotes the least significant bit.
 
    ~X[p]: Is the inversion of bit X[p]. Also equal to 1-X[p],
    (1+X[p])mod(2).
@@ -167,7 +167,7 @@
 
 
    Overflow/Overflow indicates an error in computation of signed
-   arrithmetic.  i.e. given X,Y in [MINn..MAXn]; overflow
+   arithmetic.  i.e. given X,Y in [MINn..MAXn]; overflow
    indicates that the result X+Y > MAXn or X+Y < MIN_INTx.
 
    Hardware traditionally implements overflow by computing the XOR of
@@ -179,7 +179,7 @@
    Addition - Overflow - method 1:
 
 
-   Overflow occures when the sign (most significant bit) of the two N
+   Overflow occurs when the sign (most significant bit) of the two N
    bit operands is identical but different to the sign of the result:
 
                 Rn = (Xn + Yn)
@@ -191,7 +191,7 @@
 
 
    The two N bit operands are sign extended to M>N bits and then
-   added.  Overflow occures when SIGN_BIT<n> and SIGN_BIT<m> do not
+   added.  Overflow occurs when SIGN_BIT<n> and SIGN_BIT<m> do not
    match.
   
    		Rm = (SEXTn (Xn) + SEXTn (Yn))
@@ -203,7 +203,7 @@
 
 
    The two N bit operands are sign extended to M>N bits and then
-   added.  Overflow occures when the result is outside of the sign
+   added.  Overflow occurs when the result is outside of the sign
    extended range [MINn .. MAXn].
 
 
@@ -235,7 +235,7 @@
    Addition - Carry - Introduction:
 
 
-   Carry (poorly named) indicates that an overflow occured for
+   Carry (poorly named) indicates that an overflow occurred for
    unsigned N bit addition.  i.e. given X, Y in [0..UMAXn] then
    carry indicates X+Y > UMAXn or X+Y >= Un.
 
@@ -293,7 +293,7 @@
 
    Given two signed N bit numbers, a carry can be detected by treating
    the numbers as N bit unsigned and adding them using M>N unsigned
-   arrithmetic.  Carry is indicated by bit (1 << N) being set (result
+   arithmetic.  Carry is indicated by bit (1 << N) being set (result
    >= 2**N).
 
 
@@ -314,29 +314,29 @@
 		0 <= X < Un, 0 <= Y < Un
 	==>	X + Y < 2 Un
 
-   Consider Y when carry occures:
+   Consider Y when carry occurs:
 
 		X + Y >= Un, Y < Un
-	==>	(Un - X) <= Y < Un               # re-arange
+	==>	(Un - X) <= Y < Un               # rearrange
 	==>	Un <= X + Y < Un + X < 2 Un      # add Xn
 	==>	0 <= (X + Y) mod Un < X mod Un
 
-   or when carry as occured:
+   or when carry as occurred:
 
                (X + Y) mod Un < X mod Un
 
-   Consider Y when carry does not occure:
+   Consider Y when carry does not occur:
 
 		X + Y < Un
 	have	X < Un, Y >= 0
 	==>	X <= X + Y < Un
 	==>     X mod Un <= (X + Y) mod Un
 
-   or when carry has not occured:
+   or when carry has not occurred:
 
 	        ! ( (X + Y) mod Un < X mod Un)
 
-   hence we get carry by computing in N bit unsigned arrithmetic.
+   hence we get carry by computing in N bit unsigned arithmetic.
 
                 carry <- (Xn + Yn) < Xn
 
@@ -360,7 +360,7 @@
 	==>	X + ~Y + 1		# -Y = ~Y + 1
 
    In addition to the result, the equation produces Carry-out.  For
-   succeeding extended prrcision calculations, the more general
+   succeeding extended precision calculations, the more general
    equation can be used:
 
 		C[p]:R[p]  =  X[p] + ~Y[p] + C[p-1]
@@ -416,7 +416,7 @@
 
 
    Treating Xn and Yn as unsigned values then a borrow (unsigned
-   underflow) occures when:
+   underflow) occurs when:
 
 		B = Xn < Yn
 	==>	C = Xn >= Yn
@@ -491,7 +491,7 @@
 
 /* 32 bit target expressions:
 
-   Since most hosts do not support 64 (> 32) bit arrithmetic, carry
+   Since most hosts do not support 64 (> 32) bit arithmetic, carry
    method 4 and overflow method 4 are used. */
 
 #define ALU32_BEGIN(VAL) \
@@ -518,7 +518,7 @@
 /* 64 bit target expressions:
 
    Even though the host typically doesn't support native 64 bit
-   arrithmetic, it is still used. */
+   arithmetic, it is still used. */
 
 #define ALU64_BEGIN(VAL) \
 unsigned64 alu64_r = (VAL); \
@@ -132,7 +132,7 @@
 
 
-/* Twos complement aritmetic - addition/subtraction - carry/borrow
+/* Twos complement arithmetic - addition/subtraction - carry/borrow
    (or you thought you knew the answer to 0-0)
 
Index: sim-events.c
===================================================================
RCS file: /cvs/src/src/sim/common/sim-events.c,v
retrieving revision 1.3
diff -u -r1.3 sim-events.c
--- sim-events.c	2000/07/27 11:37:34	1.3
+++ sim-events.c	2002/02/10 07:19:48
@@ -37,7 +37,7 @@
 #include <stdlib.h>
 #endif
 
-#include <signal.h> /* For SIGPROCMASK et.al. */
+#include <signal.h> /* For SIGPROCMASK et al. */
 
 typedef enum {
   watch_invalid,
@@ -112,7 +112,7 @@
    variables.
    
    TIME_OF_EVENT: this holds the time at which the next event is ment
-   to occure.  If no next event it will hold the time of the last
+   to occur.  If no next event it will hold the time of the last
    event.
 
    TIME_FROM_EVENT: The current distance from TIME_OF_EVENT.  A value
@@ -447,7 +447,7 @@
   if (delta < 0)
     sim_io_error (sd, "what is past is past!\n");
   
   /* compute when the event should occure */
   time_of_event = sim_events_time (sd) + delta;
   
   /* find the queue insertion point - things are time ordered */
@@ -447,7 +447,7 @@
     sim_io_error (sd, "what is past is past!\n");
   
-  /* compute when the event should occure */
+  /* compute when the event should occur */
   time_of_event = sim_events_time (sd) + delta;
   